@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-# $Id: query.pl,v 1.3 2001/01/27 16:21:44 rvsutherland Exp $
+# $Id: query.pl,v 1.4 2001/03/31 18:28:34 rvsutherland Exp $
 
 use strict;
 
@@ -74,12 +74,29 @@ elsif ( $action eq "resize" ){
 elsif ( $action eq "compile" ){
     $sql = $obj->compile;
 }
+elsif ( $action eq "show_space" ){
+    $sql = $obj->show_space;
+}
 else{
     die "\nDon't know how to '$action'.\n";
 } ;
 
 print $sql;
 
+# $Log: query.pl,v $
+# Revision 1.4  2001/03/31 18:28:34  rvsutherland
+# Facilitated new method 'show_space'.
+#
+# Revision 1.3  2001/01/27 16:21:44  rvsutherland
+# Added NAME section to pod.
+#
+# Revision 1.2  2001/01/14 16:47:55  rvsutherland
+# Nominal changes for version 0.32
+#
+# Revision 1.1  2001/01/07 16:42:45  rvsutherland
+# Initial Revision
+#
+
 =head1 NAME
 
 query.pl - Generates DDL for a specified list of objects.
